"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var postcss_1 = __importDefault(require("postcss"));
//@ts-expect-error
var postcss_js_1 = __importDefault(require("postcss-js"));
var transformCSS_1 = __importDefault(require("./transformCSS"));
var webpackTreat_1 = require("./webpackTreat");
function createStyleElement(id) {
    var el = document.createElement('style');
    el.id = "treat-runtime-styles-" + id;
    // Avoid Edge bug where empty style elements don't create sheets
    el.appendChild(document.createTextNode(''));
    return document.head.appendChild(el);
}
var localStyleElement = createStyleElement('local');
function serializeCSS(styles) {
    return postcss_1.default()
        .process(transformCSS_1.default(styles), { parser: postcss_js_1.default })
        .then(function (result) {
        return result.css;
    });
}
var themes = new Map();
webpackTreat_1.setWebpackTreat({
    addLocalCss: function (styles) {
        serializeCSS(styles).then(function (css) {
            localStyleElement.append(css);
        });
    },
    addThemedCss: function (themeRef, styles) {
        var styleElement = themes.get(themeRef).styleElement;
        serializeCSS(styles).then(function (css) {
            styleElement.append(css);
        });
    },
    addTheme: function (theme) {
        var styleElement = createStyleElement(theme.themeRef);
        themes.set(theme.themeRef, {
            theme: theme,
            styleElement: styleElement,
        });
    },
    getThemes: function () { return Array.from(themes.values()).map(function (_a) {
        var theme = _a.theme;
        return theme;
    }); },
    getIdentName: function (local, scopeId, theme) {
        return "" + (theme ? '_' : '') + local + scopeId;
    },
});
var builder_1 = require("./builder");
Object.defineProperty(exports, "createTheme", { enumerable: true, get: function () { return builder_1.createTheme; } });
Object.defineProperty(exports, "style", { enumerable: true, get: function () { return builder_1.style; } });
Object.defineProperty(exports, "styleMap", { enumerable: true, get: function () { return builder_1.styleMap; } });
Object.defineProperty(exports, "styleTree", { enumerable: true, get: function () { return builder_1.styleTree; } });
Object.defineProperty(exports, "globalStyle", { enumerable: true, get: function () { return builder_1.globalStyle; } });
var resolveStyles_1 = require("./resolveStyles");
Object.defineProperty(exports, "resolveStyles", { enumerable: true, get: function () { return resolveStyles_1.resolveStyles; } });
var resolveClassName_1 = require("./resolveClassName");
Object.defineProperty(exports, "resolveClassName", { enumerable: true, get: function () { return resolveClassName_1.resolveClassName; } });
