import postcss from 'postcss';
//@ts-expect-error
import postcssJs from 'postcss-js';
import transformCSS from './transformCSS';
import { setWebpackTreat } from './webpackTreat';
function createStyleElement(id) {
    var el = document.createElement('style');
    el.id = "treat-runtime-styles-" + id;
    // Avoid Edge bug where empty style elements don't create sheets
    el.appendChild(document.createTextNode(''));
    return document.head.appendChild(el);
}
var localStyleElement = createStyleElement('local');
function serializeCSS(styles) {
    return postcss()
        .process(transformCSS(styles), { parser: postcssJs })
        .then(function (result) {
        return result.css;
    });
}
var themes = new Map();
setWebpackTreat({
    addLocalCss: function (styles) {
        serializeCSS(styles).then(function (css) {
            localStyleElement.append(css);
        });
    },
    addThemedCss: function (themeRef, styles) {
        var styleElement = themes.get(themeRef).styleElement;
        serializeCSS(styles).then(function (css) {
            styleElement.append(css);
        });
    },
    addTheme: function (theme) {
        var styleElement = createStyleElement(theme.themeRef);
        themes.set(theme.themeRef, {
            theme: theme,
            styleElement: styleElement,
        });
    },
    getThemes: function () { return Array.from(themes.values()).map(function (_a) {
        var theme = _a.theme;
        return theme;
    }); },
    getIdentName: function (local, scopeId, theme) {
        return "" + (theme ? '_' : '') + local + scopeId;
    },
});
export { createTheme, style, styleMap, styleTree, globalStyle, } from './builder';
export { resolveStyles } from './resolveStyles';
export { resolveClassName } from './resolveClassName';
